@@ -103,10 +103,19 @@ if __name__ == '__main__':
     print (bool(z.is_tacto_on()))
     print (z.get_signal_temperature_value())
     print (z.get_signal_temperature_value())
-    print (z.get_is_floor_active())
+    print (z.is_floor_active())
+    print (z.is_sleep_on())
+    print (z.is_automatic_mode())
+    print (z.get_zone_mode())
+    from airzone.protocol import state_value
+    print (state_value(z._zone_state, 0, 0, 1))
+    print (format(z._zone_state[0], '016b'))
     #a.get_zones()[0].turnoff_zone()
-    
-    gateway._Machine.retrieve_machine_status()
+    print(a.get_operation_mode())
+    from airzone.protocol import MachineOperationMode
+    a.set_operation_mode('HOTPLUS')
+    a.retrieve_machine_status()
+    print(a.get_operation_mode())
     #print (a.get_zones()[0].is_zone_on())
     #print(a.get_zones()[0]._zone_state)
     #a.get_zones()[0].turnon_zone()
