@@ -93,7 +93,7 @@ class Zone():
     
     def write_bit_value(self, address, bit, value):
         new_value = change_bit_value(self._zone_state, address, bit, value)
-        self._zone_state[address] = new_value
+        #self._zone_state[address] = new_value
         self.write_register(address, new_value)
 
     def __str__(self):
@@ -144,9 +144,8 @@ class Zone():
             self.turnon_automatic_mode()
             self.turnon_sleep()
 
-
-        temp = change_range_bit_value(self._zone_state, 0, 0, 2, ZoneMode[zoneMode].value)
-        self.write_register(0, temp)
+        # temp = change_range_bit_value(self._zone_state, 0, 0, 2, ZoneMode[zoneMode].value)
+        # self.write_register(0, temp)
 
     def is_tacto_on(self):
         return bit_value(self._zone_state, 0, 2)
@@ -166,22 +165,13 @@ class Zone():
     def turnoff_hold(self):
         self.write_bit_value(0, 3, 0)
 
-    # def get_speed_selection(self):
-    #     temp = state_value(self._zone_state, 0, 4, 5)
-    #     return FancoilSpeed(temp)
-
-    # def is_zone_on(self):
-    #     temp = bit_value(self._zone_state, 0, 6)
-    #     return temp
-
-    # def turnon_zone(self):
-    #     new_value = change_bit_value(self._zone_state, 0, 6, 1)
-    #     self.write_register(0, new_value)
-
-    # def turnoff_zone(self):
-    #     new_value = change_bit_value(self._zone_state, 0, 6, 0)
-    #     self.write_register(0, new_value)
-
+    def get_speed_selection(self):
+        temp = state_value(self._zone_state, 0, 4, 5)
+        return FancoilSpeed(temp)
+    
+    def set_speed_selection(self, fancoilSpeed):
+        temp = change_range_bit_value(self._zone_state, 0, 4, 5, FancoilSpeed[fancoilSpeed].value)
+        self.write_register(0, temp)
 
     ####
 
